# ps-client

![tests](https://github.com/AnnikaCodes/ps-client/workflows/tests/badge.svg)
[![PyPI version fury.io](https://badge.fury.io/py/ps-client.svg)](https://pypi.python.org/pypi/ps-client/)
[![Documentation Status](https://readthedocs.org/projects/ps-client/badge/?version=latest)](https://ps-client.readthedocs.io/en/latest/?badge=latest)

A Python library for interacting with Pokémon Showdown. Documentation can be found [here](https://ps-client.readthedocs.io/en/latest/).
